==> kdevelop_4.6.0.orig.tar.xz: kdevelop-4.6.0/projectmanagers/custom-buildsystem/kdevcustombuildsystem.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Custom BuildSystem
Name[bs]=Vlasititi sistem gradnje
Name[ca]=BuildSystem personalitzat
Name[ca@valencia]=BuildSystem personalitzat
Name[cs]=Vlastní systém pro sestavení
Name[da]=Tilpasset byggesystem
Name[de]=Eigenes Build-System
Name[el]=Προσαρμοσμένο σύστημα κατασκευής
Name[es]=Sistema de construcción personalizado
Name[et]=Kohandatud ehitamissüsteem
Name[fi]=Oma käännösjärjestelmä
Name[fr]=Système de compilation personnalisé
Name[gl]=Sistema de compilación personalizado
Name[hu]=Egyéni fordítórendszer
Name[it]=BuildSystem personalizzato
Name[kk]=Әдеттен тыс құрастыру жүйесі
Name[nb]=Egendefinert BuildSystem
Name[nl]=Eigen bouwsysteem
Name[pl]=Własny system budowania
Name[pt]=Sistema de Compilação Personalizado
Name[pt_BR]=Sistema de compilação personalizado
Name[ru]=Собственная система сборки
Name[sk]=Vlastný buildovací systém
Name[sl]=BuildSystem po meri
Name[sv]=Eget byggsystem
Name[uk]=Нетипова система збирання
Name[x-test]=xxCustom BuildSystemxx
Name[zh_CN]=自定义构建系统
Name[zh_TW]=自訂編譯系統
Comment=Allows to use custom buildsystems for KDevelop projects
Comment[bs]=DOpušta korištene vlastitih sistema za gradnju KDevelop projekata
Comment[ca]=Permet utilitzar sistemes de construcció personalitzats per projectes del KDevelop
Comment[ca@valencia]=Permet utilitzar sistemes de construcció personalitzats per projectes del KDevelop
Comment[da]=Gør det muligt at bruge tilpassede byggesystemer til KDevelop-projekter
Comment[de]=Ermöglicht ein benutzerdefiniertes Erstellungssystem für KDevelop-Projekte
Comment[el]=Επιτρέπει τη χρήση προσαρμοσμένων συστημάτων κατασκευής για έργα KDevelop
Comment[es]=Permite usar un sistema de construcción personalizado en los proyectos de KDevelop
Comment[et]=Võimaldab kasutada KDevelopi projektide puhul kohandatud ehitamissüsteemi
Comment[fi]=Mahdollistaa omien käännösjärjestelmien käytön KDevelop-projekteissa
Comment[fr]=Toujours utiliser des systèmes de compilation personnalisés pour les projets KDevelop
Comment[gl]=Permite empregar sistemas construtores personalizados cos proxectos de KDevelop
Comment[hu]=Lehetővé teszi egyéni fordítórendszerek használatát a KDevelop projektekhez
Comment[it]=Permette di usare buildsystem personalizzati per i progetti di KDevelop
Comment[kk]=KDevelop-та пайдаланушының құрастыру жүйесін қолдану мүмкіндігі
Comment[nb]=Tillater bruk av egendefinerte byggesystemer for KDevelop-prosjekter
Comment[nl]=Staat toe eigengemaakte bouwsystemen voor projecten van KDevelop te gebruiken
Comment[pl]=Pozwala na używanie własnych systemów budowania dla projektów KDevelop
Comment[pt]=Permite usar sistemas de compilação personalizados para os projectos do KDevelop
Comment[pt_BR]=Permite usar sistemas de compilação personalizados para projetos do KDevelop
Comment[ru]=Позволяет использовать для проектов KDevelop собственные системы сборки
Comment[sk]=Povolí použiť vlastné buildovacie systémy pre projekty KDevelop
Comment[sl]=Dovoli uporabo buildsystems po meri za projekte KDevelop
Comment[sv]=Gör det möjligt att använda egna byggsystem för projekt i KDevelop
Comment[uk]=Надає змогу використовувати нетипові системи збирання у проектах KDevelop
Comment[x-test]=xxAllows to use custom buildsystems for KDevelop projectsxx
Comment[zh_CN]=允许对 KDevelop 工程使用自定义构建系统
Comment[zh_TW]=允許 KDevelop 專案使用自訂的編譯系統。
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcustombuildsystem
X-KDE-PluginInfo-Name=KDevCustomBuildSystem
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectBuilder,org.kdevelop.IProjectFileManager,org.kdevelop.IBuildSystemManager
X-KDevelop-IRequired=org.kdevelop.IOutputView,org.kdevelop.IGenericProjectManager
X-KDevelop-Mode=NoGUI

==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/projectmanagers/custom-buildsystem/kdevcustombuildsystem.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Custom BuildSystem
Name[bs]=Vlasititi sistem gradnje
Name[ca]=BuildSystem personalitzat
Name[ca@valencia]=BuildSystem personalitzat
Name[cs]=Vlastní systém pro sestavení
Name[da]=Tilpasset byggesystem
Name[de]=Eigenes Build-System
Name[el]=Προσαρμοσμένο σύστημα κατασκευής
Name[es]=Sistema de construcción personalizado
Name[et]=Kohandatud ehitamissüsteem
Name[fi]=Oma käännösjärjestelmä
Name[fr]=Système de compilation personnalisé
Name[gl]=Sistema de compilación personalizado
Name[hu]=Egyéni fordítórendszer
Name[it]=BuildSystem personalizzato
Name[kk]=Әдеттен тыс құрастыру жүйесі
Name[nb]=Egendefinert BuildSystem
Name[nl]=Eigen bouwsysteem
Name[pl]=Własny system budowania
Name[pt]=Sistema de Compilação Personalizado
Name[pt_BR]=Sistema de compilação personalizado
Name[ru]=Собственная система сборки
Name[sk]=Vlastný buildovací systém
Name[sl]=BuildSystem po meri
Name[sv]=Eget byggsystem
Name[uk]=Нетипова система збирання
Name[x-test]=xxCustom BuildSystemxx
Name[zh_CN]=自定义构建系统
Name[zh_TW]=自訂編譯系統
Comment=Allows to use custom buildsystems for KDevelop projects
Comment[bs]=DOpušta korištene vlastitih sistema za gradnju KDevelop projekata
Comment[ca]=Permet utilitzar sistemes de construcció personalitzats per projectes del KDevelop
Comment[ca@valencia]=Permet utilitzar sistemes de construcció personalitzats per projectes del KDevelop
Comment[da]=Lader dig bruge tilpassede byggesystemer til KDevelop-projekter
Comment[de]=Ermöglicht ein benutzerdefiniertes Erstellungssystem für KDevelop-Projekte
Comment[el]=Επιτρέπει τη χρήση προσαρμοσμένων συστημάτων κατασκευής για έργα KDevelop
Comment[es]=Permite usar un sistema de construcción personalizado en los proyectos de KDevelop
Comment[et]=Võimaldab kasutada KDevelopi projektide puhul kohandatud ehitamissüsteemi
Comment[fi]=Mahdollistaa omien käännösjärjestelmien käytön KDevelop-projekteissa
Comment[fr]=Toujours utiliser des systèmes de compilation personnalisés pour les projets KDevelop
Comment[gl]=Permite empregar sistemas construtores personalizados cos proxectos de KDevelop
Comment[hu]=Lehetővé teszi egyéni fordítórendszerek használatát a KDevelop projektekhez
Comment[it]=Permette di usare buildsystem personalizzati per i progetti di KDevelop
Comment[kk]=KDevelop-та пайдаланушының құрастыру жүйесін қолдану мүмкіндігі
Comment[nb]=Tillater bruk av egendefinerte byggesystemer for KDevelop-prosjekter
Comment[nl]=Staat toe eigengemaakte bouwsystemen voor projecten van KDevelop te gebruiken
Comment[pl]=Pozwala na używanie własnych systemów budowania dla projektów KDevelop
Comment[pt]=Permite usar sistemas de compilação personalizados para os projectos do KDevelop
Comment[pt_BR]=Permite usar sistemas de compilação personalizados para projetos do KDevelop
Comment[ru]=Позволяет использовать для проектов KDevelop собственные системы сборки
Comment[sk]=Povolí použiť vlastné buildovacie systémy pre projekty KDevelop
Comment[sl]=Dovoli uporabo buildsystems po meri za projekte KDevelop
Comment[sv]=Gör det möjligt att använda egna byggsystem för projekt i KDevelop
Comment[uk]=Надає змогу використовувати нетипові системи збирання у проектах KDevelop
Comment[x-test]=xxAllows to use custom buildsystems for KDevelop projectsxx
Comment[zh_CN]=允许对 KDevelop 工程使用自定义构建系统
Comment[zh_TW]=允許 KDevelop 專案使用自訂的編譯系統。
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcustombuildsystem
X-KDE-PluginInfo-Name=KDevCustomBuildSystem
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectBuilder,org.kdevelop.IProjectFileManager,org.kdevelop.IBuildSystemManager
X-KDevelop-IRequired=org.kdevelop.IOutputView,org.kdevelop.IGenericProjectManager
X-KDevelop-Mode=NoGUI
